# coding: utf-8
# Module: onscreen_label
# Created on: 17.08.2015
# Author: Roman Miroshnychenko aka Roman V.M. (romanvm@yandex.ua)
# Licence: GPL v.3: http://www.gnu.org/copyleft/gpl.html


import os
import xbmcgui
import plugintools
import xbmc

class OnScreenLabel(object):
    def __init__(self, text='', visible=False):
        self._window = xbmcgui.Window(12005)
        self._back = xbmcgui.ControlImage(10, 150, 830, 60,
                                      os.path.join(plugintools.get_runtime_path(),'resources','images', 'OverlayDialogBackground.png'))
        self._window.addControl(self._back)
        self._label = xbmcgui.ControlLabel(30, 165, 1000, 100, text, textColor='0xFFFFFFFF')
        self._window.addControl(self._label)
        if not visible:
            self.hide()

    @property
    def text(self):
        return self._label.getLabel()

    @text.setter
    def text(self, value):
        self._label.setLabel(value)

    def show(self):
        self._back.setVisible(True)
        self._label.setVisible(True)

    def hide(self):
        self._back.setVisible(False)
        self._label.setVisible(False)

VIEWPORT_WIDTH = 1920.0
VIEWPORT_HEIGHT = 1088.0
OVERLAY_WIDTH = int(VIEWPORT_WIDTH * 0.7) # 70% size
OVERLAY_HEIGHT = 150
WINDOW_FULLSCREEN_VIDEO = 12005

class OverlayText(object):
    def __init__(self, w=OVERLAY_WIDTH, h=OVERLAY_HEIGHT, *args, **kwargs):
        self.window = xbmcgui.Window(WINDOW_FULLSCREEN_VIDEO)
        viewport_w, viewport_h = self._get_skin_resolution()
        # Adjust size based on viewport, we are using 1080p coordinates
        w = 830
        h = 600
        x = (viewport_w - w) / 2
        y = (viewport_h - h) / 2
        self._shown = False
        self._text = ""
        self._label = xbmcgui.ControlLabel(x, y, w, h, self._text, *args, **kwargs)
        self._background = xbmcgui.ControlImage(x, y, w, h, os.path.join(plugintools.get_runtime_path(),'resources','images', 'black.png'))
        self._background.setColorDiffuse("0xD0000000")

    def show(self):
        if not self._shown:
            self.window.addControls([self._background, self._label])
            self._shown = True

    def hide(self):
        if self._shown:
            self._shown = False
            self.window.removeControls([self._background, self._label])

    def close(self):
        self.hide()

    @property
    def text(self):
        return self._text

    @text.setter
    def text(self, text):
        self._text = text
        if self._shown:
            self._label.setLabel(self._text)

    # This is so hackish it hurts.
    def _get_skin_resolution(self):
        import xml.etree.ElementTree as ET
        skin_path = xbmc.translatePath("special://skin/")
        tree = ET.parse(os.path.join(skin_path, "addon.xml"))
        res = tree.findall("./extension/res")[0]
        return int(res.attrib["width"]), int(res.attrib["height"])